StreetViewController class

Constructors

StreetViewController(WebViewController webViewController)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webViewController → WebViewController
final

Methods

addMarker(double lat, double lng) Future<void>
changeLocation(double lat, double lng) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeMarker() Future<void>
setApiKey(String apiKey) Future<void>
setCustomIcon(String base64Icon, double scaledWidth, double scaledHeight, double anchorX, double anchorY) Future<void>
setOptions(StreetViewOptions options) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited