MarkerOptions class
Constructors
- MarkerOptions({double? markerLat, double? markerLng, MarkerIconType iconType = MarkerIconType.defaultIcon, String? customIconPath, double scaledWidth = 40, double scaledHeight = 40, double anchorX = 0, double anchorY = 50})
-
const
Properties
- anchorX → double
-
final
- anchorY → double
-
final
- customIconPath → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMarker → bool
-
no setter
- iconType → MarkerIconType
-
final
- markerLat → double?
-
final
- markerLng → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaledHeight → double
-
final
- scaledWidth → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited