StreetViewOptions class
Constructors
- StreetViewOptions({bool panControl = true, bool zoomControl = true, bool linksControl = true, bool fullscreenControl = true, bool motionTrackingControl = true, bool addressControl = true, bool showRoadLabels = true, bool clickToGo = true, bool scrollwheel = true, bool disableDefaultUI = false, int povHeading = 0, int povPitch = 0, int povZoom = 0})
-
const
Properties
- addressControl → bool
-
final
- clickToGo → bool
-
final
- disableDefaultUI → bool
-
final
- fullscreenControl → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- linksControl → bool
-
final
- motionTrackingControl → bool
-
final
- panControl → bool
-
final
- povHeading → int
-
final
- povPitch → int
-
final
- povZoom → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollwheel → bool
-
final
- showRoadLabels → bool
-
final
- zoomControl → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited